pub struct BmpEncoder<'a, W>where
W: 'a,{ /* private fields */ }Expand description
The representation of a BMP encoder.
Implementations
Sourceimpl<'a, W> BmpEncoder<'a, W>where
W: Write + 'a,
impl<'a, W> BmpEncoder<'a, W>where
W: Write + 'a,
Sourcepub fn new(w: &'a mut W) -> BmpEncoder<'a, W>
pub fn new(w: &'a mut W) -> BmpEncoder<'a, W>
Create a new encoder that writes its output to w.
Sourcepub fn encode(
&mut self,
image: &[u8],
width: u32,
height: u32,
c: ColorType,
) -> Result<(), ImageError>
pub fn encode( &mut self, image: &[u8], width: u32, height: u32, c: ColorType, ) -> Result<(), ImageError>
Encodes the image image that has dimensions width and height and ColorType c.
Panics
Panics if width * height * c.bytes_per_pixel() != image.len().
Sourcepub fn encode_with_palette(
&mut self,
image: &[u8],
width: u32,
height: u32,
c: ColorType,
palette: Option<&[[u8; 3]]>,
) -> Result<(), ImageError>
pub fn encode_with_palette( &mut self, image: &[u8], width: u32, height: u32, c: ColorType, palette: Option<&[[u8; 3]]>, ) -> Result<(), ImageError>
Same as encode, but allow a palette to be passed in. The palette is ignored for color
types other than Luma/Luma-with-alpha.
Panics
Panics if width * height * c.bytes_per_pixel() != image.len().